@@ -13,12 +13,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 import proto  # type: ignore
 
 from google.cloud.clouddms_v1.types import clouddms_resources
-from google.protobuf import field_mask_pb2  # type: ignore
-from google.protobuf import timestamp_pb2  # type: ignore
-
 
 __protobuf__ = proto.module(
     package="google.cloud.clouddms.v1",
@@ -91,24 +92,39 @@ class ListMigrationJobsRequest(proto.Message):
             "name desc".
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by: str = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListMigrationJobsResponse(proto.Message):
     r"""Response message for 'ListMigrationJobs' request.
 
     Attributes:
-        migration_jobs (Sequence[google.cloud.clouddms_v1.types.MigrationJob]):
+        migration_jobs (MutableSequence[google.cloud.clouddms_v1.types.MigrationJob]):
             The list of migration jobs objects.
         next_page_token (str):
             A token, which can be sent as ``page_token`` to retrieve the
             next page. If this field is omitted, there are no subsequent
             pages.
-        unreachable (Sequence[str]):
+        unreachable (MutableSequence[str]):
             Locations that could not be reached.
     """
 
@@ -116,11 +132,21 @@ class ListMigrationJobsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    migration_jobs = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=clouddms_resources.MigrationJob,
+    migration_jobs: MutableSequence[
+        clouddms_resources.MigrationJob
+    ] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=clouddms_resources.MigrationJob,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable: MutableSequence[str] = proto.RepeatedField(
+        proto.STRING,
+        number=3,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
 
 
 class GetMigrationJobRequest(proto.Message):
@@ -132,7 +158,10 @@ class GetMigrationJobRequest(proto.Message):
             to get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateMigrationJobRequest(proto.Message):
@@ -161,12 +190,23 @@ class CreateMigrationJobRequest(proto.Message):
             characters.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    migration_job_id = proto.Field(proto.STRING, number=2,)
-    migration_job = proto.Field(
-        proto.MESSAGE, number=3, message=clouddms_resources.MigrationJob,
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    migration_job_id: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    migration_job: clouddms_resources.MigrationJob = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=clouddms_resources.MigrationJob,
+    )
+    request_id: str = proto.Field(
+        proto.STRING,
+        number=4,
     )
-    request_id = proto.Field(proto.STRING, number=4,)
 
 
 class UpdateMigrationJobRequest(proto.Message):
@@ -192,13 +232,20 @@ class UpdateMigrationJobRequest(proto.Message):
             characters.
     """
 
-    update_mask = proto.Field(
-        proto.MESSAGE, number=1, message=field_mask_pb2.FieldMask,
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=field_mask_pb2.FieldMask,
     )
-    migration_job = proto.Field(
-        proto.MESSAGE, number=2, message=clouddms_resources.MigrationJob,
+    migration_job: clouddms_resources.MigrationJob = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=clouddms_resources.MigrationJob,
+    )
+    request_id: str = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    request_id = proto.Field(proto.STRING, number=3,)
 
 
 class DeleteMigrationJobRequest(proto.Message):
@@ -225,9 +272,18 @@ class DeleteMigrationJobRequest(proto.Message):
             replica database is also deleted.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=2,)
-    force = proto.Field(proto.BOOL, number=3,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    force: bool = proto.Field(
+        proto.BOOL,
+        number=3,
+    )
 
 
 class StartMigrationJobRequest(proto.Message):
@@ -238,7 +294,10 @@ class StartMigrationJobRequest(proto.Message):
             Name of the migration job resource to start.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class StopMigrationJobRequest(proto.Message):
@@ -249,7 +308,10 @@ class StopMigrationJobRequest(proto.Message):
             Name of the migration job resource to stop.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ResumeMigrationJobRequest(proto.Message):
@@ -260,7 +322,10 @@ class ResumeMigrationJobRequest(proto.Message):
             Name of the migration job resource to resume.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class PromoteMigrationJobRequest(proto.Message):
@@ -272,7 +337,10 @@ class PromoteMigrationJobRequest(proto.Message):
             promote.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class VerifyMigrationJobRequest(proto.Message):
@@ -283,7 +351,10 @@ class VerifyMigrationJobRequest(proto.Message):
             Name of the migration job resource to verify.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class RestartMigrationJobRequest(proto.Message):
@@ -295,7 +366,10 @@ class RestartMigrationJobRequest(proto.Message):
             restart.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class GenerateSshScriptRequest(proto.Message):
@@ -328,15 +402,30 @@ class GenerateSshScriptRequest(proto.Message):
             host
     """
 
-    migration_job = proto.Field(proto.STRING, number=1,)
-    vm = proto.Field(proto.STRING, number=2,)
-    vm_creation_config = proto.Field(
-        proto.MESSAGE, number=100, oneof="vm_config", message="VmCreationConfig",
+    migration_job: str = proto.Field(
+        proto.STRING,
+        number=1,
     )
-    vm_selection_config = proto.Field(
-        proto.MESSAGE, number=101, oneof="vm_config", message="VmSelectionConfig",
+    vm: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    vm_creation_config: "VmCreationConfig" = proto.Field(
+        proto.MESSAGE,
+        number=100,
+        oneof="vm_config",
+        message="VmCreationConfig",
+    )
+    vm_selection_config: "VmSelectionConfig" = proto.Field(
+        proto.MESSAGE,
+        number=101,
+        oneof="vm_config",
+        message="VmSelectionConfig",
+    )
+    vm_port: int = proto.Field(
+        proto.INT32,
+        number=3,
     )
-    vm_port = proto.Field(proto.INT32, number=3,)
 
 
 class VmCreationConfig(proto.Message):
@@ -353,9 +442,18 @@ class VmCreationConfig(proto.Message):
             in.
     """
 
-    vm_machine_type = proto.Field(proto.STRING, number=1,)
-    vm_zone = proto.Field(proto.STRING, number=2,)
-    subnet = proto.Field(proto.STRING, number=3,)
+    vm_machine_type: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    vm_zone: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    subnet: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class VmSelectionConfig(proto.Message):
@@ -367,7 +465,10 @@ class VmSelectionConfig(proto.Message):
             VM is located.
     """
 
-    vm_zone = proto.Field(proto.STRING, number=1,)
+    vm_zone: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class SshScript(proto.Message):
@@ -378,7 +479,10 @@ class SshScript(proto.Message):
             The ssh configuration script.
     """
 
-    script = proto.Field(proto.STRING, number=1,)
+    script: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListConnectionProfilesRequest(proto.Message):
@@ -418,24 +522,39 @@ class ListConnectionProfilesRequest(proto.Message):
             the order by fields for the result.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by: str = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListConnectionProfilesResponse(proto.Message):
     r"""Response message for 'ListConnectionProfiles' request.
 
     Attributes:
-        connection_profiles (Sequence[google.cloud.clouddms_v1.types.ConnectionProfile]):
+        connection_profiles (MutableSequence[google.cloud.clouddms_v1.types.ConnectionProfile]):
             The response list of connection profiles.
         next_page_token (str):
             A token, which can be sent as ``page_token`` to retrieve the
             next page. If this field is omitted, there are no subsequent
             pages.
-        unreachable (Sequence[str]):
+        unreachable (MutableSequence[str]):
             Locations that could not be reached.
     """
 
@@ -443,11 +562,21 @@ class ListConnectionProfilesResponse(proto.Message):
     def raw_page(self):
         return self
 
-    connection_profiles = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=clouddms_resources.ConnectionProfile,
+    connection_profiles: MutableSequence[
+        clouddms_resources.ConnectionProfile
+    ] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=clouddms_resources.ConnectionProfile,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable: MutableSequence[str] = proto.RepeatedField(
+        proto.STRING,
+        number=3,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
 
 
 class GetConnectionProfileRequest(proto.Message):
@@ -459,7 +588,10 @@ class GetConnectionProfileRequest(proto.Message):
             resource to get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateConnectionProfileRequest(proto.Message):
@@ -486,12 +618,23 @@ class CreateConnectionProfileRequest(proto.Message):
             characters.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    connection_profile_id = proto.Field(proto.STRING, number=2,)
-    connection_profile = proto.Field(
-        proto.MESSAGE, number=3, message=clouddms_resources.ConnectionProfile,
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    connection_profile_id: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    connection_profile: clouddms_resources.ConnectionProfile = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=clouddms_resources.ConnectionProfile,
+    )
+    request_id: str = proto.Field(
+        proto.STRING,
+        number=4,
     )
-    request_id = proto.Field(proto.STRING, number=4,)
 
 
 class UpdateConnectionProfileRequest(proto.Message):
@@ -517,13 +660,20 @@ class UpdateConnectionProfileRequest(proto.Message):
             characters.
     """
 
-    update_mask = proto.Field(
-        proto.MESSAGE, number=1, message=field_mask_pb2.FieldMask,
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=field_mask_pb2.FieldMask,
     )
-    connection_profile = proto.Field(
-        proto.MESSAGE, number=2, message=clouddms_resources.ConnectionProfile,
+    connection_profile: clouddms_resources.ConnectionProfile = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=clouddms_resources.ConnectionProfile,
+    )
+    request_id: str = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    request_id = proto.Field(proto.STRING, number=3,)
 
 
 class DeleteConnectionProfileRequest(proto.Message):
@@ -549,9 +699,18 @@ class DeleteConnectionProfileRequest(proto.Message):
             connection profile).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=2,)
-    force = proto.Field(proto.BOOL, number=3,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    force: bool = proto.Field(
+        proto.BOOL,
+        number=3,
+    )
 
 
 class OperationMetadata(proto.Message):
@@ -584,13 +743,36 @@ class OperationMetadata(proto.Message):
             operation.
     """
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    target = proto.Field(proto.STRING, number=3,)
-    verb = proto.Field(proto.STRING, number=4,)
-    status_message = proto.Field(proto.STRING, number=5,)
-    requested_cancellation = proto.Field(proto.BOOL, number=6,)
-    api_version = proto.Field(proto.STRING, number=7,)
+    create_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    target: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    verb: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    status_message: str = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    requested_cancellation: bool = proto.Field(
+        proto.BOOL,
+        number=6,
+    )
+    api_version: str = proto.Field(
+        proto.STRING,
+        number=7,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
