@@ -13,13 +13,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
+from typing import MutableMapping, MutableSequence
 
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.protobuf import wrappers_pb2  # type: ignore
 from google.rpc import status_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.clouddms.v1",
@@ -89,10 +89,23 @@ class SslConfig(proto.Message):
         SERVER_ONLY = 1
         SERVER_CLIENT = 2
 
-    type_ = proto.Field(proto.ENUM, number=1, enum=SslType,)
-    client_key = proto.Field(proto.STRING, number=2,)
-    client_certificate = proto.Field(proto.STRING, number=3,)
-    ca_certificate = proto.Field(proto.STRING, number=4,)
+    type_: SslType = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=SslType,
+    )
+    client_key: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    client_certificate: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    ca_certificate: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class MySqlConnectionProfile(proto.Message):
@@ -130,13 +143,35 @@ class MySqlConnectionProfile(proto.Message):
             of the source.
     """
 
-    host = proto.Field(proto.STRING, number=1,)
-    port = proto.Field(proto.INT32, number=2,)
-    username = proto.Field(proto.STRING, number=3,)
-    password = proto.Field(proto.STRING, number=4,)
-    password_set = proto.Field(proto.BOOL, number=5,)
-    ssl = proto.Field(proto.MESSAGE, number=6, message="SslConfig",)
-    cloud_sql_id = proto.Field(proto.STRING, number=7,)
+    host: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    port: int = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    username: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    password: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    password_set: bool = proto.Field(
+        proto.BOOL,
+        number=5,
+    )
+    ssl: "SslConfig" = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message="SslConfig",
+    )
+    cloud_sql_id: str = proto.Field(
+        proto.STRING,
+        number=7,
+    )
 
 
 class PostgreSqlConnectionProfile(proto.Message):
@@ -174,13 +209,35 @@ class PostgreSqlConnectionProfile(proto.Message):
             of the source.
     """
 
-    host = proto.Field(proto.STRING, number=1,)
-    port = proto.Field(proto.INT32, number=2,)
-    username = proto.Field(proto.STRING, number=3,)
-    password = proto.Field(proto.STRING, number=4,)
-    password_set = proto.Field(proto.BOOL, number=5,)
-    ssl = proto.Field(proto.MESSAGE, number=6, message="SslConfig",)
-    cloud_sql_id = proto.Field(proto.STRING, number=7,)
+    host: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    port: int = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    username: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    password: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    password_set: bool = proto.Field(
+        proto.BOOL,
+        number=5,
+    )
+    ssl: "SslConfig" = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message="SslConfig",
+    )
+    cloud_sql_id: str = proto.Field(
+        proto.STRING,
+        number=7,
+    )
 
 
 class CloudSqlConnectionProfile(proto.Message):
@@ -203,10 +260,23 @@ class CloudSqlConnectionProfile(proto.Message):
             instance's public IP.
     """
 
-    cloud_sql_id = proto.Field(proto.STRING, number=1,)
-    settings = proto.Field(proto.MESSAGE, number=2, message="CloudSqlSettings",)
-    private_ip = proto.Field(proto.STRING, number=3,)
-    public_ip = proto.Field(proto.STRING, number=4,)
+    cloud_sql_id: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    settings: "CloudSqlSettings" = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="CloudSqlSettings",
+    )
+    private_ip: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    public_ip: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class SqlAclEntry(proto.Message):
@@ -238,14 +308,26 @@ class SqlAclEntry(proto.Message):
             A label to identify this entry.
     """
 
-    value = proto.Field(proto.STRING, number=1,)
-    expire_time = proto.Field(
-        proto.MESSAGE, number=10, oneof="expiration", message=timestamp_pb2.Timestamp,
+    value: str = proto.Field(
+        proto.STRING,
+        number=1,
     )
-    ttl = proto.Field(
-        proto.MESSAGE, number=11, oneof="expiration", message=duration_pb2.Duration,
+    expire_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=10,
+        oneof="expiration",
+        message=timestamp_pb2.Timestamp,
+    )
+    ttl: duration_pb2.Duration = proto.Field(
+        proto.MESSAGE,
+        number=11,
+        oneof="expiration",
+        message=duration_pb2.Duration,
+    )
+    label: str = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    label = proto.Field(proto.STRING, number=3,)
 
 
 class SqlIpConfig(proto.Message):
@@ -263,18 +345,31 @@ class SqlIpConfig(proto.Message):
         require_ssl (google.protobuf.wrappers_pb2.BoolValue):
             Whether SSL connections over IP should be
             enforced or not.
-        authorized_networks (Sequence[google.cloud.clouddms_v1.types.SqlAclEntry]):
+        authorized_networks (MutableSequence[google.cloud.clouddms_v1.types.SqlAclEntry]):
             The list of external networks that are allowed to connect to
             the instance using the IP. See
             https://en.wikipedia.org/wiki/CIDR_notation#CIDR_notation,
             also known as 'slash' notation (e.g. ``192.168.100.0/24``).
     """
 
-    enable_ipv4 = proto.Field(proto.MESSAGE, number=1, message=wrappers_pb2.BoolValue,)
-    private_network = proto.Field(proto.STRING, number=2,)
-    require_ssl = proto.Field(proto.MESSAGE, number=3, message=wrappers_pb2.BoolValue,)
-    authorized_networks = proto.RepeatedField(
-        proto.MESSAGE, number=4, message="SqlAclEntry",
+    enable_ipv4: wrappers_pb2.BoolValue = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=wrappers_pb2.BoolValue,
+    )
+    private_network: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    require_ssl: wrappers_pb2.BoolValue = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=wrappers_pb2.BoolValue,
+    )
+    authorized_networks: MutableSequence["SqlAclEntry"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=4,
+        message="SqlAclEntry",
     )
 
 
@@ -284,7 +379,7 @@ class CloudSqlSettings(proto.Message):
     Attributes:
         database_version (google.cloud.clouddms_v1.types.CloudSqlSettings.SqlDatabaseVersion):
             The database engine type and version.
-        user_labels (Sequence[google.cloud.clouddms_v1.types.CloudSqlSettings.UserLabelsEntry]):
+        user_labels (MutableMapping[str, str]):
             The resource labels for a Cloud SQL instance to use to
             annotate any related underlying resources such as Compute
             Engine VMs. An object containing a list of "key": "value"
@@ -326,7 +421,7 @@ class CloudSqlSettings(proto.Message):
             available storage repeatedly falls below the threshold size,
             Cloud SQL continues to add storage until it reaches the
             maximum of 30 TB.
-        database_flags (Sequence[google.cloud.clouddms_v1.types.CloudSqlSettings.DatabaseFlagsEntry]):
+        database_flags (MutableMapping[str, str]):
             The database flags passed to the Cloud SQL
             instance at startup. An object containing a list
             of "key": value pairs. Example: { "name":
@@ -378,27 +473,75 @@ class CloudSqlSettings(proto.Message):
         POSTGRES_12 = 7
         POSTGRES_13 = 8
 
-    database_version = proto.Field(proto.ENUM, number=1, enum=SqlDatabaseVersion,)
-    user_labels = proto.MapField(proto.STRING, proto.STRING, number=2,)
-    tier = proto.Field(proto.STRING, number=3,)
-    storage_auto_resize_limit = proto.Field(
-        proto.MESSAGE, number=4, message=wrappers_pb2.Int64Value,
+    database_version: SqlDatabaseVersion = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=SqlDatabaseVersion,
     )
-    activation_policy = proto.Field(proto.ENUM, number=5, enum=SqlActivationPolicy,)
-    ip_config = proto.Field(proto.MESSAGE, number=6, message="SqlIpConfig",)
-    auto_storage_increase = proto.Field(
-        proto.MESSAGE, number=7, message=wrappers_pb2.BoolValue,
+    user_labels: MutableMapping[str, str] = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=2,
     )
-    database_flags = proto.MapField(proto.STRING, proto.STRING, number=8,)
-    data_disk_type = proto.Field(proto.ENUM, number=9, enum=SqlDataDiskType,)
-    data_disk_size_gb = proto.Field(
-        proto.MESSAGE, number=10, message=wrappers_pb2.Int64Value,
+    tier: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    storage_auto_resize_limit: wrappers_pb2.Int64Value = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=wrappers_pb2.Int64Value,
+    )
+    activation_policy: SqlActivationPolicy = proto.Field(
+        proto.ENUM,
+        number=5,
+        enum=SqlActivationPolicy,
+    )
+    ip_config: "SqlIpConfig" = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message="SqlIpConfig",
+    )
+    auto_storage_increase: wrappers_pb2.BoolValue = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message=wrappers_pb2.BoolValue,
+    )
+    database_flags: MutableMapping[str, str] = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=8,
+    )
+    data_disk_type: SqlDataDiskType = proto.Field(
+        proto.ENUM,
+        number=9,
+        enum=SqlDataDiskType,
+    )
+    data_disk_size_gb: wrappers_pb2.Int64Value = proto.Field(
+        proto.MESSAGE,
+        number=10,
+        message=wrappers_pb2.Int64Value,
+    )
+    zone: str = proto.Field(
+        proto.STRING,
+        number=11,
+    )
+    source_id: str = proto.Field(
+        proto.STRING,
+        number=12,
+    )
+    root_password: str = proto.Field(
+        proto.STRING,
+        number=13,
+    )
+    root_password_set: bool = proto.Field(
+        proto.BOOL,
+        number=14,
+    )
+    collation: str = proto.Field(
+        proto.STRING,
+        number=15,
     )
-    zone = proto.Field(proto.STRING, number=11,)
-    source_id = proto.Field(proto.STRING, number=12,)
-    root_password = proto.Field(proto.STRING, number=13,)
-    root_password_set = proto.Field(proto.BOOL, number=14,)
-    collation = proto.Field(proto.STRING, number=15,)
 
 
 class StaticIpConnectivity(proto.Message):
@@ -437,10 +580,22 @@ class ReverseSshConnectivity(proto.Message):
             SQL private network.
     """
 
-    vm_ip = proto.Field(proto.STRING, number=1,)
-    vm_port = proto.Field(proto.INT32, number=2,)
-    vm = proto.Field(proto.STRING, number=3,)
-    vpc = proto.Field(proto.STRING, number=4,)
+    vm_ip: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    vm_port: int = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    vm: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    vpc: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class VpcPeeringConnectivity(proto.Message):
@@ -454,7 +609,10 @@ class VpcPeeringConnectivity(proto.Message):
             Cloud SQL private network.
     """
 
-    vpc = proto.Field(proto.STRING, number=1,)
+    vpc: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class DatabaseType(proto.Message):
@@ -467,8 +625,16 @@ class DatabaseType(proto.Message):
             The database engine.
     """
 
-    provider = proto.Field(proto.ENUM, number=1, enum="DatabaseProvider",)
-    engine = proto.Field(proto.ENUM, number=2, enum="DatabaseEngine",)
+    provider: "DatabaseProvider" = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum="DatabaseProvider",
+    )
+    engine: "DatabaseEngine" = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum="DatabaseEngine",
+    )
 
 
 class MigrationJob(proto.Message):
@@ -497,7 +663,7 @@ class MigrationJob(proto.Message):
             RFC3339 UTC "Zulu" format, accurate to
             nanoseconds. Example:
             "2014-10-02T15:01:23.045123456Z".
-        labels (Sequence[google.cloud.clouddms_v1.types.MigrationJob.LabelsEntry]):
+        labels (MutableMapping[str, str]):
             The resource labels for migration job to use to annotate any
             related underlying resources such as Compute Engine VMs. An
             object containing a list of "key": "value" pairs.
@@ -589,39 +755,99 @@ class MigrationJob(proto.Message):
         ONE_TIME = 1
         CONTINUOUS = 2
 
-    name = proto.Field(proto.STRING, number=1,)
-    create_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=4,)
-    display_name = proto.Field(proto.STRING, number=5,)
-    state = proto.Field(proto.ENUM, number=6, enum=State,)
-    phase = proto.Field(proto.ENUM, number=7, enum=Phase,)
-    type_ = proto.Field(proto.ENUM, number=8, enum=Type,)
-    dump_path = proto.Field(proto.STRING, number=9,)
-    source = proto.Field(proto.STRING, number=10,)
-    destination = proto.Field(proto.STRING, number=11,)
-    reverse_ssh_connectivity = proto.Field(
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    create_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels: MutableMapping[str, str] = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=4,
+    )
+    display_name: str = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    state: State = proto.Field(
+        proto.ENUM,
+        number=6,
+        enum=State,
+    )
+    phase: Phase = proto.Field(
+        proto.ENUM,
+        number=7,
+        enum=Phase,
+    )
+    type_: Type = proto.Field(
+        proto.ENUM,
+        number=8,
+        enum=Type,
+    )
+    dump_path: str = proto.Field(
+        proto.STRING,
+        number=9,
+    )
+    source: str = proto.Field(
+        proto.STRING,
+        number=10,
+    )
+    destination: str = proto.Field(
+        proto.STRING,
+        number=11,
+    )
+    reverse_ssh_connectivity: "ReverseSshConnectivity" = proto.Field(
         proto.MESSAGE,
         number=101,
         oneof="connectivity",
         message="ReverseSshConnectivity",
     )
-    vpc_peering_connectivity = proto.Field(
+    vpc_peering_connectivity: "VpcPeeringConnectivity" = proto.Field(
         proto.MESSAGE,
         number=102,
         oneof="connectivity",
         message="VpcPeeringConnectivity",
     )
-    static_ip_connectivity = proto.Field(
-        proto.MESSAGE, number=103, oneof="connectivity", message="StaticIpConnectivity",
+    static_ip_connectivity: "StaticIpConnectivity" = proto.Field(
+        proto.MESSAGE,
+        number=103,
+        oneof="connectivity",
+        message="StaticIpConnectivity",
     )
-    duration = proto.Field(proto.MESSAGE, number=12, message=duration_pb2.Duration,)
-    error = proto.Field(proto.MESSAGE, number=13, message=status_pb2.Status,)
-    source_database = proto.Field(proto.MESSAGE, number=14, message="DatabaseType",)
-    destination_database = proto.Field(
-        proto.MESSAGE, number=15, message="DatabaseType",
+    duration: duration_pb2.Duration = proto.Field(
+        proto.MESSAGE,
+        number=12,
+        message=duration_pb2.Duration,
+    )
+    error: status_pb2.Status = proto.Field(
+        proto.MESSAGE,
+        number=13,
+        message=status_pb2.Status,
+    )
+    source_database: "DatabaseType" = proto.Field(
+        proto.MESSAGE,
+        number=14,
+        message="DatabaseType",
+    )
+    destination_database: "DatabaseType" = proto.Field(
+        proto.MESSAGE,
+        number=15,
+        message="DatabaseType",
+    )
+    end_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=16,
+        message=timestamp_pb2.Timestamp,
     )
-    end_time = proto.Field(proto.MESSAGE, number=16, message=timestamp_pb2.Timestamp,)
 
 
 class ConnectionProfile(proto.Message):
@@ -649,7 +875,7 @@ class ConnectionProfile(proto.Message):
             was last updated. A timestamp in RFC3339 UTC
             "Zulu" format, accurate to nanoseconds. Example:
             "2014-10-02T15:01:23.045123456Z".
-        labels (Sequence[google.cloud.clouddms_v1.types.ConnectionProfile.LabelsEntry]):
+        labels (MutableMapping[str, str]):
             The resource labels for connection profile to use to
             annotate any related underlying resources such as Compute
             Engine VMs. An object containing a list of "key": "value"
@@ -694,32 +920,62 @@ class ConnectionProfile(proto.Message):
         DELETED = 6
         FAILED = 7
 
-    name = proto.Field(proto.STRING, number=1,)
-    create_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=4,)
-    state = proto.Field(proto.ENUM, number=5, enum=State,)
-    display_name = proto.Field(proto.STRING, number=6,)
-    mysql = proto.Field(
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    create_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels: MutableMapping[str, str] = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=4,
+    )
+    state: State = proto.Field(
+        proto.ENUM,
+        number=5,
+        enum=State,
+    )
+    display_name: str = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    mysql: "MySqlConnectionProfile" = proto.Field(
         proto.MESSAGE,
         number=100,
         oneof="connection_profile",
         message="MySqlConnectionProfile",
     )
-    postgresql = proto.Field(
+    postgresql: "PostgreSqlConnectionProfile" = proto.Field(
         proto.MESSAGE,
         number=101,
         oneof="connection_profile",
         message="PostgreSqlConnectionProfile",
     )
-    cloudsql = proto.Field(
+    cloudsql: "CloudSqlConnectionProfile" = proto.Field(
         proto.MESSAGE,
         number=102,
         oneof="connection_profile",
         message="CloudSqlConnectionProfile",
     )
-    error = proto.Field(proto.MESSAGE, number=7, message=status_pb2.Status,)
-    provider = proto.Field(proto.ENUM, number=8, enum="DatabaseProvider",)
+    error: status_pb2.Status = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message=status_pb2.Status,
+    )
+    provider: "DatabaseProvider" = proto.Field(
+        proto.ENUM,
+        number=8,
+        enum="DatabaseProvider",
+    )
 
 
 class MigrationJobVerificationError(proto.Message):
@@ -762,9 +1018,19 @@ class MigrationJobVerificationError(proto.Message):
         UNSUPPORTED_DEFINER = 19
         CANT_RESTART_RUNNING_MIGRATION = 21
 
-    error_code = proto.Field(proto.ENUM, number=1, enum=ErrorCode,)
-    error_message = proto.Field(proto.STRING, number=2,)
-    error_detail_message = proto.Field(proto.STRING, number=3,)
+    error_code: ErrorCode = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=ErrorCode,
+    )
+    error_message: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    error_detail_message: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
